==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Layer/ts/Layer_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+54"/>
        <source>&amp;Layer</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
&amp;Camada
Utilize a &amp;camada atual</translatorcomment>
        <translation>&amp;Camada</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+136"/>
        <source>Leading or trailing spaces.</source>
        <translation>Esquerda ou à direita espaços.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nome da camada está vazia.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Camada já existe.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dados da camada</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Nome da Camada:
Nome da camada:</translatorcomment>
        <translation>Nome da camada:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Pen</source>
        <translatorcomment>--exact match--
--file: pt.po--
Abrindo o arquivo recente...
Abrindo o arquivo recente
Abertura abortada</translatorcomment>
        <translation>Caneta</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Cor da &amp;Grade:
Cor da Grade:
Cor da &amp;Meta Grade:</translatorcomment>
        <translation>Cor:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Lineweight:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Espessura de linha:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Linetype:</source>
        <translatorcomment>--ignored colon--
--file: LinetypeSettings_pt.ts--</translatorcomment>
        <translation>Tipo de linha:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Layer/ts/Layer_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation>Ferramentas de Camada</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Exiba as ferramentas de camada</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translatorcomment>--exact match--
--file: qcad_pt.ts--
&amp;Camada
Utilize a &amp;camada atual</translatorcomment>
        <translation>&amp;Camada</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espaços à esquerda ou à direita.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O nome da camada está em branco.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Esta camada já existe.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dados da Camada</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Nome da Camada:
Nome da camada:</translatorcomment>
        <translation>Nome da camada:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translatorcomment>--exact match--
--file: pt.po--
Abrindo o arquivo recente...
Abrindo o arquivo recente
Abertura abortada</translatorcomment>
        <translation type="vanished">Caneta</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Atributos</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Cor da &amp;Grade:
Cor da Grade:
Cor da &amp;Meta Grade:</translatorcomment>
        <translation>Cor:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Espessura da linha:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translatorcomment>--ignored colon--
--file: LinetypeSettings_pt.ts--</translatorcomment>
        <translation>Tipo de linha:</translation>
    </message>
</context>
</TS>
